"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CSVLogger = void 0;
const csv_stringify_1 = require("csv-stringify");
const fs_1 = require("fs");
const path = require("path");
const IpcBusLogUtils_1 = require("./IpcBusLogUtils");
class CSVLogger {
    constructor(filename) {
        (0, IpcBusLogUtils_1.ensureDirSync)(path.dirname(filename));
        try {
            (0, fs_1.unlinkSync)(filename);
        }
        catch (_a) {
        }
        const options = {
            header: true,
            quoted: true,
            columns: [
                { key: 'timestamp', header: 'timestamp' },
                { key: 'id', header: 'id' },
                { key: 'order', header: 'order' },
                { key: 'channel', header: 'channel' },
                { key: 'kindStr', header: 'kind' },
                { key: 'peer_id', header: 'peer id' },
                { key: 'delay', header: 'delay' },
                { key: 'local', header: 'local' },
                { key: 'peer', header: 'peer' },
                { key: 'peer_related', header: 'peer related' },
                { key: 'request', header: 'request' },
                { key: 'payload', header: 'payload' },
                { key: 'arg0', header: 'arg0' },
                { key: 'arg1', header: 'arg1' },
                { key: 'arg2', header: 'arg2' },
                { key: 'arg3', header: 'arg3' },
                { key: 'arg4', header: 'arg4' },
                { key: 'arg5', header: 'arg5' },
                { key: 'arg6', header: 'arg6' },
            ],
        };
        this._stringify = (0, csv_stringify_1.stringify)(options);
        this._stringify.pipe((0, fs_1.createWriteStream)(filename, { highWaterMark: 1024 }));
    }
    writeLog(message) {
        const csvJsonLog = message;
        csvJsonLog.local = message.local ? 'local' : '';
        const args = message.args;
        if (args) {
            for (let i = 0, l = Math.min(args.length, 7); i < l; ++i) {
                csvJsonLog[`arg${i}`] = args[i];
            }
        }
        csvJsonLog.request = message.responseChannel ? `${message.responseChannel} => ${message.responseStatus}` : '';
        this._stringify.write(csvJsonLog);
    }
}
exports.CSVLogger = CSVLogger;
//# sourceMappingURL=IpcBusCSVLogger.js.map