"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SetLogLevel = exports.IpcBusLogConfigMain = void 0;
const universal_1 = require("@electron-common-ipc/universal");
const json_helpers_1 = require("json-helpers");
const socket_serializer_1 = require("socket-serializer");
const IpcBusLog_1 = require("./IpcBusLog");
const IpcBusLog_factory_main_1 = require("./IpcBusLog-factory-main");
const IpcBusLogUtils_1 = require("./IpcBusLogUtils");
class IpcBusLogConfigMain extends universal_1.IpcBusLogConfigImpl {
    constructor() {
        super();
        this._order = 0;
    }
    getCallback() {
        return this._cb;
    }
    setCallback(cb) {
        this._cb = cb;
    }
    getArgs(args) {
        if (args === undefined) {
            return [];
        }
        if (this._argMaxContentLen <= 0) {
            return args;
        }
        const managedArgs = [];
        for (let i = 0, l = args.length; i < l; ++i) {
            managedArgs.push((0, IpcBusLogUtils_1.cutData)(args[i], this._argMaxContentLen));
        }
        return managedArgs;
    }
    buildMessage(ipcMessage, args, payload) {
        ipcMessage = ipcMessage;
        if (ipcMessage.stamp === undefined) {
            return undefined;
        }
        let kind;
        switch (ipcMessage.kind) {
            case "MES":
                kind = ipcMessage.request ? 2 : 0;
                break;
            case "RQR":
                kind = 4;
                break;
            case "LOGRT":
                kind = ipcMessage.stamp.kind;
                break;
            default:
                return undefined;
        }
        const needArgs = (this._level & universal_1.ContractLogLevel.Args) === universal_1.ContractLogLevel.Args;
        const local = ipcMessage.stamp.local || ipcMessage.stamp.responseLocal;
        const message = {
            kind,
            kindStr: (0, IpcBusLog_1.LogKindToStr)(kind),
            id: ipcMessage.stamp.id,
            peer: ipcMessage.stamp.peer,
            relatedPeer: ipcMessage.stamp.peerReceived,
            local,
            payload,
            args: needArgs ? this.getArgs(args) : undefined,
        };
        switch (message.kind) {
            case 2:
            case 0: {
                message.order = 0;
                message.timestamp = ipcMessage.stamp.timestamp - this._baseTime;
                (message.delay = 0), (message.channel = ipcMessage.channel);
                message.responseChannel = ipcMessage.request && ipcMessage.request.id;
                break;
            }
            case 3:
            case 1: {
                message.order = 1;
                message.timestamp = ipcMessage.stamp.timestampReceived - this._baseTime;
                message.delay = ipcMessage.stamp.timestampReceived - ipcMessage.stamp.timestamp;
                message.channel = ipcMessage.channel;
                message.responseChannel = ipcMessage.request && ipcMessage.request.id;
                break;
            }
            case 4: {
                message.order = 2;
                message.timestamp = ipcMessage.stamp.timestampResponse - this._baseTime;
                message.delay = ipcMessage.stamp.timestampResponse - ipcMessage.stamp.timestampReceived;
                message.channel = ipcMessage.request.channel;
                message.responseChannel = ipcMessage.request.id;
                message.responseStatus = ipcMessage.request.resolve ? 'resolved' : 'rejected';
                break;
            }
            case 5: {
                message.order = 3;
                message.timestamp = ipcMessage.stamp.timestampResponseReceived - this._baseTime;
                message.delay = ipcMessage.stamp.timestampResponseReceived - ipcMessage.stamp.timestampResponse;
                message.channel = ipcMessage.request.channel;
                message.responseChannel = ipcMessage.request.id;
                message.responseStatus = ipcMessage.request.resolve ? 'resolved' : 'rejected';
                break;
            }
        }
        this._cb(message);
        return message;
    }
    _addLog(ipcMessage, args, payload) {
        this.buildMessage(ipcMessage, args, payload);
        return ipcMessage.kind !== "LOGRT";
    }
    addLog(ipcMessage, args) {
        const packet = new socket_serializer_1.IpcPacketBuffer();
        const packetSize = packet.bytelength(args);
        return this._addLog(ipcMessage, args, packetSize);
    }
    addLogRawContent(ipcMessage, rawData) {
        const ipcPacketBufferCore = rawData.buffer ? new socket_serializer_1.IpcPacketBuffer(rawData) : new socket_serializer_1.IpcPacketBufferList(rawData);
        ipcPacketBufferCore.JSON = json_helpers_1.JSONParserV1;
        return this._addLog(ipcMessage, ipcPacketBufferCore.parseArrayLength() > 1 ? ipcPacketBufferCore.parseArrayAt(1) : undefined, ipcPacketBufferCore.packetSize);
    }
    addLogPacket(ipcMessage, ipcPacketBuffer) {
        return this._addLog(ipcMessage, ipcPacketBuffer.parseArrayLength() > 1 ? ipcPacketBuffer.parseArrayAt(1) : undefined, ipcPacketBuffer.packetSize);
    }
}
exports.IpcBusLogConfigMain = IpcBusLogConfigMain;
const SetLogLevel = (level, cb, argContentLen) => {
    const logger = (0, IpcBusLog_factory_main_1.CreateIpcBusLog)();
    logger.level = level;
    logger.setCallback(cb);
    logger.argMaxContentLen = argContentLen;
};
exports.SetLogLevel = SetLogLevel;
//# sourceMappingURL=IpcBusLogConfig-main.js.map