"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cutData = exports.jsonStringifyString = exports.jsonStringifyObject = exports.stringifyJsonArray = exports.jsonStringify = exports.ensureDirSync = void 0;
const fs_1 = require("fs");
const util = require("util");
const CutMarker = "'__cut__'";
function ensureDirSync(path) {
    if (!(0, fs_1.existsSync)(path)) {
        (0, fs_1.mkdirSync)(path, { recursive: true });
    }
}
exports.ensureDirSync = ensureDirSync;
function jsonStringify(data, maxLen) {
    let output = '';
    switch (typeof data) {
        case 'object':
            if (Buffer.isBuffer(data)) {
                if (data.length > maxLen * 2) {
                    output = data.toString('utf8', 0, maxLen) + CutMarker;
                }
                else {
                    output = data.toString('utf8', 0, maxLen);
                }
            }
            else if (Array.isArray(data)) {
                output = stringifyJsonArray(data, maxLen, output);
            }
            else if (util.types.isDate(data)) {
                output = data.toISOString();
            }
            else {
                output = jsonStringifyObject(data, maxLen, output);
            }
            break;
        case 'string':
            output = jsonStringifyString(data, maxLen);
            break;
        case 'number':
            output = data.toString();
            break;
        case 'boolean':
            output = data ? 'true' : 'false';
            break;
        case 'undefined':
            output = '__undefined__';
            break;
    }
    return output;
}
exports.jsonStringify = jsonStringify;
function stringifyJsonArray(data, maxLen, output) {
    output += '[';
    for (let i = 0, l = data.length; i < l; ++i) {
        if (output.length >= maxLen) {
            output += CutMarker;
            break;
        }
        output += jsonStringify(data[i], maxLen - output.length);
        output += ',';
    }
    output += ']';
    return output;
}
exports.stringifyJsonArray = stringifyJsonArray;
function jsonStringifyObject(data, maxLen, output) {
    output += '{';
    if (data) {
        const keys = Object.keys(data);
        for (let i = 0, l = keys.length; i < l; ++i) {
            if (output.length >= maxLen) {
                output += CutMarker;
                break;
            }
            const key = keys[i];
            output += key + ': ';
            if (output.length >= maxLen) {
                output += CutMarker;
                break;
            }
            output += jsonStringify(data[key], maxLen - output.length);
            output += ',';
        }
    }
    else {
        output += 'null';
    }
    output += '}';
    return output;
}
exports.jsonStringifyObject = jsonStringifyObject;
function jsonStringifyString(data, maxLen) {
    if (data.length > maxLen) {
        return data.substring(0, maxLen) + CutMarker;
    }
    return data;
}
exports.jsonStringifyString = jsonStringifyString;
function cutData(data, maxLen) {
    switch (typeof data) {
        case 'object':
        case 'string':
            return jsonStringify(data, maxLen);
        default:
            return data;
    }
}
exports.cutData = cutData;
//# sourceMappingURL=IpcBusLogUtils.js.map