"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.newIpcBusBridge = void 0;
const universal_1 = require("@electron-common-ipc/universal");
const path = require("path");
const IpcBusBridgeImpl_1 = require("./IpcBusBridgeImpl");
const IpcBusBridgeLogger_1 = require("./IpcBusBridgeLogger");
const IpcBusCSVLogger_main_1 = require("../log/IpcBusCSVLogger-main");
const IpcBusJSONLogger_main_1 = require("../log/IpcBusJSONLogger-main");
const IpcBusLog_factory_main_1 = require("../log/IpcBusLog-factory-main");
const log_1 = require("../utils/log");
const uuid_1 = require("../utils/uuid");
function newIpcBusBridgeInternal() {
    const contractLogger = (0, IpcBusLog_factory_main_1.CreateIpcBusLog)();
    if (process.env['ELECTRON_IPC_LOG_CSV']) {
        if (contractLogger.level === universal_1.ContractLogLevel.None) {
            contractLogger.level = universal_1.ContractLogLevel.Args;
        }
        if (contractLogger.argMaxContentLen < 0) {
            contractLogger.argMaxContentLen = 255;
        }
        const filename = path.join(process.env['ELECTRON_IPC_LOG_CSV'], 'electron-common-ipc.csv');
        (0, IpcBusCSVLogger_main_1.setLogLevelCVS)(contractLogger.level, filename, contractLogger.argMaxContentLen);
    }
    if (process.env['ELECTRON_IPC_LOG_JSON']) {
        if (contractLogger.level === universal_1.ContractLogLevel.None) {
            contractLogger.level = universal_1.ContractLogLevel.Args;
        }
        if (contractLogger.argMaxContentLen < 0) {
            contractLogger.argMaxContentLen = 255;
        }
        const filename = path.join(process.env['ELECTRON_IPC_LOG_JSON'], 'electron-common-ipc.json');
        (0, IpcBusJSONLogger_main_1.setLogLevelJSON)(contractLogger.level, filename, contractLogger.argMaxContentLen);
    }
    let bridge;
    const logger = log_1.Logger.enable ? new universal_1.ConsoleLogger() : undefined;
    if (contractLogger.level > universal_1.ContractLogLevel.None) {
        bridge = new IpcBusBridgeLogger_1.IpcBusBridgeLogger(6, contractLogger, uuid_1.uuidProvider, new universal_1.MessageStampImpl(contractLogger), logger);
    }
    else {
        bridge = new IpcBusBridgeImpl_1.IpcBusBridgeImpl(6, uuid_1.uuidProvider, undefined, logger);
    }
    return bridge;
}
const gBridgeSymbolName = 'IpcBusBridge';
function newIpcBusBridge() {
    const globalContainer = new universal_1.GlobalContainer();
    let gBridge = globalContainer.getSingleton(gBridgeSymbolName);
    if (gBridge === undefined) {
        gBridge = newIpcBusBridgeInternal();
        globalContainer.registerSingleton(gBridgeSymbolName, gBridge);
    }
    return gBridge;
}
exports.newIpcBusBridge = newIpcBusBridge;
//# sourceMappingURL=IpcBusBridge-factory.js.map