/// <reference types="electron" />
import { IpcBusProcessType } from '@electron-common-ipc/universal';
import { IpcBusBridgeTransportMain } from './IpcBusMainBridge';
import { IpcBusQueryStateManager } from './IpcBusQueryState-collector';
import { IpcBusRendererBridge } from './IpcBusRendererBridge';
import { SerializeMessage } from '../utils/IpcBusCommand-helpers';
import type { BridgeCloseOptions, BridgeConnectOptions, IpcBusBridge } from './IpcBusBridge';
import type { ClientCloseOptions, ClientConnectOptions, IpcBusPeer, Logger, MessageStamp, UuidProvider, IpcBusMessage, IpcBusTransport, QueryStateBase, IpcBusCommand } from '@electron-common-ipc/universal';
import type { IpcPacketBuffer, IpcPacketBufferCore } from 'socket-serializer';
export interface IpcBusBridgeClient {
    getChannels(): string[];
    isTarget(ipcMessage: IpcBusMessage): boolean;
    broadcastConnect(options: ClientConnectOptions): Promise<void>;
    broadcastClose(options?: ClientCloseOptions): Promise<void>;
    broadcastCommand(ipcCommand: IpcBusCommand): void;
    broadcastPacket(ipcMessage: IpcBusMessage, ipcPacketBufferCore: IpcPacketBufferCore): boolean;
    broadcastData(ipcMessage: IpcBusMessage, data: IpcPacketBuffer.RawData | unknown[], messagePorts?: Electron.MessagePortMain[]): boolean;
    queryState(): QueryStateBase;
}
export interface IpcBusBridgeDispatcher {
    _onRendererCommandReceived(ipcCommand: IpcBusCommand): void;
    _onRendererLogReceived(ipcMessage: IpcBusMessage, data: IpcPacketBufferCore.RawData | unknown[]): void;
    _onRendererMessageReceived(ipcMessage: IpcBusMessage, data: IpcPacketBufferCore.RawData | unknown[], messagePorts?: Electron.MessagePortMain[]): void;
    _onMainCommandReceived(ipcCommand: IpcBusCommand): void;
    _onMainLogReceived(ipcMessage: IpcBusMessage, args: unknown[]): void;
    _onMainMessageReceived(ipcMessage: IpcBusMessage, args: unknown[], messagePorts?: Electron.MessagePortMain[]): void;
    _onSocketCommandReceived(ipcCommand: IpcBusCommand): void;
    _onSocketLogReceived(ipcMessage: IpcBusMessage, ipcPacketBufferCore: IpcPacketBufferCore): void;
    _onSocketMessageReceived(ipcMessage: IpcBusMessage, ipcPacketBufferCore: IpcPacketBufferCore): boolean;
    _onSocketRequestResponseReceived(ipcResponse: IpcBusMessage, ipcPacketBufferCore?: IpcPacketBufferCore): boolean;
}
export declare class IpcBusBridgeImpl implements IpcBusBridge, IpcBusBridgeDispatcher {
    private readonly _uuid;
    private readonly _stamp?;
    private readonly _logger?;
    protected _mainTransport: IpcBusBridgeTransportMain;
    protected _socketTransport: IpcBusBridgeClient;
    protected _rendererConnector: IpcBusRendererBridge;
    protected _serializeMessage: SerializeMessage;
    protected _queryStateManager: IpcBusQueryStateManager;
    constructor(contextType: IpcBusProcessType, _uuid: UuidProvider, _stamp?: MessageStamp, _logger?: Logger);
    get mainTransport(): IpcBusTransport;
    get rendererTransport(): IpcBusRendererBridge;
    get socketTransport(): IpcBusBridgeClient;
    getWindowTarget(window: Electron.BrowserWindow, frameId?: number): IpcBusPeer | undefined;
    connect(arg1: BridgeConnectOptions | string | number, arg2?: BridgeConnectOptions | string, arg3?: BridgeConnectOptions): Promise<void>;
    close(_options?: BridgeCloseOptions): Promise<void>;
    startQueryState(): void;
    getQueryState(): Map<string, QueryStateBase[]>;
    getChannels(): string[];
    _onBridgeChannelChanged(ipcCommand: IpcBusCommand): void;
    _onRendererCommandReceived(ipcCommand: IpcBusCommand): void;
    _onRendererLogReceived(_ipcMessage: IpcBusMessage, _data: IpcPacketBufferCore.RawData | unknown[]): void;
    _onRendererMessageReceived(ipcMessage: IpcBusMessage, data: IpcPacketBufferCore.RawData | unknown[], messagePorts?: Electron.MessagePortMain[]): void;
    _onMainCommandReceived(ipcCommand: IpcBusCommand): void;
    _onMainLogReceived(_ipcMessage: IpcBusMessage, _args: unknown[]): void;
    _onMainMessageReceived(ipcMessage: IpcBusMessage, args: unknown[], messagePorts?: Electron.MessagePortMain[]): void;
    _onSocketCommandReceived(ipcCommand: IpcBusCommand): void;
    _onSocketLogReceived(_ipcMessage: IpcBusMessage, _ipcPacketBufferCore: IpcPacketBufferCore): void;
    _onSocketMessageReceived(ipcMessage: IpcBusMessage, ipcPacketBufferCore: IpcPacketBufferCore): boolean;
    _onSocketRequestResponseReceived(ipcResponse: IpcBusMessage, ipcPacketBufferCore?: IpcPacketBufferCore): boolean;
    _onSocketClosed(): void;
}
