"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IpcBusBrokerBridge = void 0;
const universal_1 = require("@electron-common-ipc/universal");
const NetBrokerServerFactory_1 = require("../node/NetBrokerServerFactory");
const utils_1 = require("../utils");
const IpcBusCommand_helpers_1 = require("../utils/IpcBusCommand-helpers");
class IpcBusBrokerBridge extends universal_1.BrokerImpl {
    constructor(contextType, bridge, logger) {
        super(new NetBrokerServerFactory_1.NetBrokerServerFactory(logger), contextType, logger);
        this._bridge = bridge;
    }
    queryState() {
        return super._queryState();
    }
    isTarget(ipcMessage) {
        if (this._subscriptions.hasChannel(ipcMessage.channel)) {
            return true;
        }
        return (0, IpcBusCommand_helpers_1.GetTargetProcess)(ipcMessage) !== undefined;
    }
    getChannels() {
        return this._subscriptions.getChannels();
    }
    broadcastConnect(options) {
        return super.connect(options).then(() => { });
    }
    broadcastClose(options) {
        return super.close(options).then(() => { });
    }
    broadcastCommand(_ipcCommand) {
        throw 'TODO';
    }
    broadcastData(ipcMessage, data) {
        if (ipcMessage.isRawData) {
            const rawData = data;
            if (rawData.buffer) {
                return this.broadcastBuffers(ipcMessage, [rawData.buffer]);
            }
            return this.broadcastBuffers(ipcMessage, rawData.buffers);
        }
        throw 'not supported';
    }
    broadcastPacket(ipcMessage, ipcPacketBufferCore) {
        return this.broadcastBuffers(ipcMessage, ipcPacketBufferCore.buffers);
    }
    broadcastBuffers(ipcMessage, buffers) {
        const target = (0, IpcBusCommand_helpers_1.GetTargetProcess)(ipcMessage);
        if (target) {
            const endpoint = this._endpoints.get(target.id);
            if (endpoint) {
                endpoint.socket.send((0, utils_1.buffersToList)(buffers));
                return true;
            }
        }
        if (ipcMessage.kind === "MES") {
            this._subscriptions.forEachChannel(ipcMessage.channel, (connData) => {
                connData.data.socket.send((0, utils_1.buffersToList)(buffers));
            });
        }
        return false;
    }
    _reset() {
        super._reset();
        this._bridge._onSocketClosed();
    }
    broadcastCommandToBridge(ipcCommand) {
        this._bridge._onSocketCommandReceived(ipcCommand);
    }
    broadcastToBridge(_client, ipcMessage, ipcPacketBufferList) {
        if (ipcMessage.kind === "RQR") {
            this._bridge._onSocketRequestResponseReceived(ipcMessage, ipcPacketBufferList);
        }
        else {
            this._bridge._onSocketMessageReceived(ipcMessage, ipcPacketBufferList);
        }
    }
}
exports.IpcBusBrokerBridge = IpcBusBrokerBridge;
//# sourceMappingURL=IpcBusBrokerBridge.js.map