"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IpcBusQueryStateManager = void 0;
require("@electron-common-ipc/universal");
const uuid_1 = require("../utils/uuid");
class IpcBusQueryStateManager {
    constructor(bridge, _log = false) {
        this._log = _log;
        this._bridge = bridge;
        this.processes = new Map();
    }
    start() {
        this.processes.clear();
        this._session = (0, uuid_1.uuidProvider)();
        const ipcQueryState = {
            kind: "QUST",
            peer: { id: 'query-state-collector', type: 6 },
            channel: this._session,
        };
        const rendererQueryState = this._bridge.rendererTransport.queryState();
        this.collect({ id: this._session, queryState: rendererQueryState });
        this._bridge.rendererTransport.broadcastCommand(ipcQueryState);
        this._bridge.mainTransport.onConnectorCommandBase(ipcQueryState);
        if (this._bridge.socketTransport) {
            const socketQueryState = this._bridge.socketTransport.queryState();
            this.collect({ id: this._session, queryState: socketQueryState });
            this._bridge.socketTransport.broadcastCommand(ipcQueryState);
        }
    }
    collect(queryStateResponse) {
        if (queryStateResponse.id !== this._session) {
            return;
        }
        let processEntry = this.processes.get(queryStateResponse.queryState.contextId);
        if (!processEntry) {
            processEntry = [queryStateResponse.queryState];
            this.processes.set(queryStateResponse.queryState.contextId, processEntry);
        }
        else {
            processEntry.push(queryStateResponse.queryState);
        }
        this._log && console.log(`QueryState: ${JSON.stringify(queryStateResponse, undefined, 4)}`);
    }
}
exports.IpcBusQueryStateManager = IpcBusQueryStateManager;
//# sourceMappingURL=IpcBusQueryState-collector.js.map