/// <reference types="electron" />
/// <reference types="node" />
import type { IpcBusBridgeImpl, IpcBusBridgeClient } from './IpcBusBridgeImpl';
import type { ClientCloseOptions, ClientConnectOptions, IpcBusPeer, IpcBusProcess, IpcBusCommand, IpcBusMessage, QueryStateBase, IpcBusProcessType } from '@electron-common-ipc/universal';
import type { IpcPacketBuffer, IpcPacketBufferCore } from 'socket-serializer';
export interface IpcBusRendererPeer extends IpcBusPeer {
    process: IpcBusProcess;
}
export declare class IpcBusRendererBridge implements IpcBusBridgeClient {
    private readonly _contextType;
    private readonly _bridge;
    private readonly _ipcMain;
    private readonly _subscriptions;
    private readonly _endpoints;
    private readonly _earlyIPCIssueFixed;
    constructor(contextType: IpcBusProcessType, bridge: IpcBusBridgeImpl);
    getWindowTarget(window: Electron.BrowserWindow, frameId?: number): IpcBusPeer | undefined;
    isTarget(ipcMessage: IpcBusMessage): boolean;
    getChannels(): string[];
    broadcastConnect(_options: ClientConnectOptions): Promise<void>;
    broadcastClose(_options?: ClientCloseOptions): Promise<void>;
    private _onHandshakeReceived;
    private _trackRendererDestruction;
    private deleteEndpointKey;
    private _onEndpointHandshake;
    private _onEndpointShutdown;
    broadcastCommand(ipcCommand: IpcBusCommand): void;
    broadcastBuffers(_ipcMessage: IpcBusMessage, _buffers: Buffer[]): boolean;
    broadcastPacket(ipcMessage: IpcBusMessage, ipcPacketBufferCore: IpcPacketBufferCore): boolean;
    broadcastData(ipcMessage: IpcBusMessage, data: IpcPacketBuffer.RawData | unknown[], messagePorts?: Electron.MessagePortMain[]): boolean;
    private _broadcastData;
    private _onIPCLogReceived;
    private _onIPCCommandReceived;
    private _addListeners;
    private _removeListeners;
    private _onPortCommandReceived;
    private _onIPCMessageReceived;
    private _onPortMessageReceived;
    queryState(): QueryStateBase;
}
