"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IpcBusTransportSocketBridge = void 0;
const universal_1 = require("@electron-common-ipc/universal");
const socket_serializer_1 = require("socket-serializer");
const IpcBusCommand_helpers_1 = require("../utils/IpcBusCommand-helpers");
const PeerName = 'IPCBus:NetBridge';
class IpcBusTransportSocketBridge extends universal_1.IpcBusTransportImpl {
    constructor(connector, bridge, uuid, stamp, logger) {
        super(connector, uuid, stamp, logger);
        this._mockPeer = { id: 'transport-socket', type: this.connector.type };
        this._mockClient = { peer: this._mockPeer, listeners: () => [] };
        this._bridge = bridge;
        this._subscribedChannels = new universal_1.ChannelsRefCount();
    }
    broadcastConnect(options) {
        return super.connect(this._mockClient, Object.assign(Object.assign({}, options), { peerName: PeerName })).then(() => {
            var _a;
            const channels = this._bridge.getChannels();
            this._postCommand({
                kind: "BICOO",
                peer: this._mockPeer,
                channel: undefined,
                channels,
            });
            (_a = this._logger) === null || _a === void 0 ? void 0 : _a.info(`${PeerName} Installed`);
        });
    }
    broadcastClose(options) {
        this._postCommand({
            kind: "BICOC",
            peer: this._mockPeer,
            channel: '',
        });
        return super.close(this._mockClient, options);
    }
    broadcastCommand(ipcCommand) {
        this._postCommand(ipcCommand);
    }
    broadcastData(ipcMessage, data, messagePorts) {
        if (ipcMessage.isRawData) {
            const rawData = data;
            if (rawData.buffer) {
                return this._broadcastBuffers(ipcMessage, [rawData.buffer]);
            }
            return this._broadcastBuffers(ipcMessage, rawData.buffers);
        }
        const args = data;
        this._postMessage(ipcMessage, args, messagePorts);
        return false;
    }
    _broadcastBuffers(_ipcMessage, buffers) {
        const connector = this.connector;
        if (connector.socket) {
            (0, socket_serializer_1.WriteBuffersToSocket)(connector.socket, buffers);
        }
        return false;
    }
    broadcastPacket(ipcMessage, ipcPacketBufferCore) {
        return this._broadcastBuffers(ipcMessage, ipcPacketBufferCore.buffers);
    }
    isTarget(ipcMessage) {
        if (this._subscribedChannels.has(ipcMessage.channel)) {
            return true;
        }
        return (0, IpcBusCommand_helpers_1.GetTargetProcess)(ipcMessage) !== undefined;
    }
    getChannels() {
        return this._subscribedChannels.getChannels();
    }
    addChannel() {
        throw 'not implemented';
    }
    removeChannel() {
    }
    onLogReceived(ipcMessage, args, buffers) {
        this._bridge._onSocketLogReceived(ipcMessage, buffers);
    }
    onMessageReceived(_local, ipcMessage, _args, ipcPacketBufferCore, _messagePorts) {
        return this._bridge._onSocketMessageReceived(ipcMessage, ipcPacketBufferCore);
    }
    onRequestResponseReceived(_local, ipcResponse, _args, ipcPacketBufferCore) {
        return this._bridge._onSocketRequestResponseReceived(ipcResponse, ipcPacketBufferCore);
    }
    onConnectorCommandBase(ipcCommand) {
        switch (ipcCommand.kind) {
            case "LICA":
                this._subscribedChannels.addRef(ipcCommand.channel);
                break;
            case "LICR":
                this._subscribedChannels.release(ipcCommand.channel);
                break;
            case "QUST":
            case "QUSTR":
                this._bridge._onSocketCommandReceived(ipcCommand);
                break;
        }
    }
    onConnectorShutdown() {
        super.onConnectorShutdown();
        this._subscribedChannels.clear();
        this._bridge._onSocketClosed();
    }
    queryState() {
        const peersJSON = {};
        const processChannelsJSON = {};
        const channels = this._subscribedChannels.getChannels();
        for (let i = 0; i < channels.length; ++i) {
            const channel = channels[i];
            const processChannelJSON = (processChannelsJSON[channel] = {
                name: channel,
                refCount: 0,
            });
            const refCount = this._subscribedChannels.get(channel);
            processChannelJSON.refCount += refCount;
        }
        const results = {
            type: 'transport-socket-bridge',
            contextId: (0, universal_1.createContextId)(this.connector.type),
            process: { pid: process.pid },
            channels: processChannelsJSON,
            peers: peersJSON,
        };
        return results;
    }
}
exports.IpcBusTransportSocketBridge = IpcBusTransportSocketBridge;
//# sourceMappingURL=IpcBusSocketBridge.js.map