"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IpcBusBrokerNode = void 0;
const universal_1 = require("@electron-common-ipc/universal");
const json_helpers_1 = require("json-helpers");
const socket_serializer_1 = require("socket-serializer");
class IpcBusBrokerNode extends universal_1.BrokerImpl {
    constructor(serverFactory, logger) {
        super(serverFactory, 1, logger);
        this._packetOut = new socket_serializer_1.IpcPacketWriter();
        this._packetOut.JSON = json_helpers_1.JSONParserV1;
        this._subscribedChannels = new universal_1.ChannelsRefCount();
    }
    _reset() {
        this.onBridgeClosed();
        super._reset();
    }
    onBridgeConnected(socketClient, ipcCommand) {
        if (!this._socketWriter) {
            this._brokerClient = socketClient;
            const realClient = socketClient;
            this._socketWriter = new socket_serializer_1.SocketWriter(realClient.socket);
            if (Array.isArray(ipcCommand.channels)) {
                this._subscribedChannels.addRefs(ipcCommand.channels);
            }
            const bridgeMockPeer = { id: 'broker-node', type: this._contextType };
            const channels = this._subscriptions.getChannels();
            for (let i = 0, l = channels.length; i < l; ++i) {
                this.broadcastCommandToBridge({
                    kind: "LICA",
                    peer: bridgeMockPeer,
                    channel: channels[i],
                });
            }
            this._subscriptions.client = {
                channelAdded: (channel) => {
                    this.broadcastCommandToBridge({
                        kind: "LICA",
                        peer: bridgeMockPeer,
                        channel,
                    });
                },
                channelRemoved: (channel) => {
                    this.broadcastCommandToBridge({
                        kind: "LICR",
                        peer: bridgeMockPeer,
                        channel,
                    });
                },
            };
        }
    }
    onBridgeClosed(client) {
        if (this._socketWriter && (client === undefined || client === this._brokerClient)) {
            this._subscriptions.client = undefined;
            this._socketWriter = undefined;
            this._subscribedChannels.clear();
        }
    }
    onBridgeAddChannel(ipcCommand) {
        this._subscribedChannels.addRef(ipcCommand.channel);
    }
    onBridgeRemoveChannel(ipcCommand) {
        this._subscribedChannels.release(ipcCommand.channel);
    }
    broadcastCommandToBridge(ipcCommand) {
        this._packetOut.write(this._socketWriter, [ipcCommand]);
    }
    broadcastToBridge(client, _ipcMessage, ipcPacketBufferList) {
        if (this._socketWriter && client !== this._brokerClient) {
            (0, socket_serializer_1.WriteBuffersToSocket)(this._socketWriter.socket, ipcPacketBufferList.buffers);
        }
    }
}
exports.IpcBusBrokerNode = IpcBusBrokerNode;
//# sourceMappingURL=IpcBusBrokerNode.js.map