"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NetBrokerClient = void 0;
const json_helpers_1 = require("json-helpers");
const socket_serializer_1 = require("socket-serializer");
class NetBrokerClient {
    constructor(socket, _logger) {
        var _a;
        this.socket = socket;
        this._logger = _logger;
        (_a = this._logger) === null || _a === void 0 ? void 0 : _a.info(`[IPCBus:BrokerSocket] Connect: ${this.socket.remotePort}`);
        this._bufferListReader = new socket_serializer_1.BufferListReader();
        this._packetIn = new socket_serializer_1.IpcPacketBufferList();
        this._packetIn.JSON = json_helpers_1.JSONParserV1;
        this._socketBinds = {};
        this._socketBinds['error'] = this.onSocketError.bind(this);
        this._socketBinds['close'] = this.onSocketClose.bind(this);
        this._socketBinds['data'] = this.onSocketData.bind(this);
        this._socketBinds['end'] = this.onSocketEnd.bind(this);
        for (const key in this._socketBinds) {
            this.socket.addListener(key, this._socketBinds[key]);
        }
    }
    send(bufferList) {
        if (this.socket) {
            (0, socket_serializer_1.WriteBuffersToSocket)(this.socket, bufferList.buffers);
        }
    }
    [Symbol.toPrimitive]() {
        return `NetSocket: ${this.socket.remoteAddress}:${this.socket.localPort}`;
    }
    subscribe(onSocketData, onSocketError, onSocketClose) {
        this._onSocketClientData = onSocketData;
        this._onSocketClientError = onSocketError;
        this._onSocketClientClose = onSocketClose;
    }
    release() {
        var _a;
        (_a = this._logger) === null || _a === void 0 ? void 0 : _a.info(`[IPCBus:BrokerSocket] Release: ${this.socket.remotePort}`);
        if (this._onSocketClientData) {
            for (const key in this._socketBinds) {
                this.socket.removeListener(key, this._socketBinds[key]);
            }
            this.socket.on('error', (err) => {
                var _a;
                this.socket.removeAllListeners();
                (_a = this._logger) === null || _a === void 0 ? void 0 : _a.warn(`[NetBrokerClient] Released socket error: ${err}`);
                this.socket.destroy();
            });
            this.socket.end();
            this.socket.unref();
            this._onSocketClientData = undefined;
            this._onSocketClientClose = undefined;
            this._onSocketClientError = undefined;
        }
    }
    onSocketData(buffer) {
        this._bufferListReader.appendBuffer(buffer);
        if (this._packetIn.decodeFromReader(this._bufferListReader)) {
            do {
                const ipcCommand = this._packetIn.parseArrayAt(0);
                this._onSocketClientData(this, ipcCommand, this._packetIn);
            } while (this._packetIn.decodeFromReader(this._bufferListReader));
            this._bufferListReader.reduce();
        }
    }
    onSocketError(error) {
        var _a, _b;
        (_a = this._logger) === null || _a === void 0 ? void 0 : _a.info(`[IPCBus:Broker] Error on connection: ${this.socket.remotePort} - ${error}`);
        (_b = this._onSocketClientError) === null || _b === void 0 ? void 0 : _b.call(this, this, error);
    }
    onSocketClose() {
        var _a, _b;
        (_a = this._logger) === null || _a === void 0 ? void 0 : _a.info(`[IPCBus:Broker] Close on connection: ${this.socket.remotePort}`);
        (_b = this._onSocketClientClose) === null || _b === void 0 ? void 0 : _b.call(this, this);
        this.release();
    }
    onSocketEnd() {
        var _a, _b;
        (_a = this._logger) === null || _a === void 0 ? void 0 : _a.info(`[IPCBus:Broker] End on connection: ${this.socket.remotePort}`);
        (_b = this._onSocketClientClose) === null || _b === void 0 ? void 0 : _b.call(this, this);
    }
}
exports.NetBrokerClient = NetBrokerClient;
//# sourceMappingURL=NetBrokerClient.js.map