"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NetBrokerServer = void 0;
const universal_1 = require("@electron-common-ipc/universal");
const NetBrokerClient_1 = require("./NetBrokerClient");
class NetBrokerServer {
    constructor(_server, _logger) {
        this._server = _server;
        this._logger = _logger;
        this._onClose = this._onClose.bind(this);
        this._onError = this._onError.bind(this);
        this._onConnection = this._onConnection.bind(this);
    }
    close(options) {
        if (!this._server) {
            return Promise.resolve();
        }
        return (0, universal_1.executeInTimeout)(options === null || options === void 0 ? void 0 : options.timeoutDelay, (resolve) => {
            this._server.removeAllListeners();
            this._server.addListener('close', () => {
                this._server.removeAllListeners();
                this._server = undefined;
                resolve();
            });
            this._server.addListener('error', (err) => {
                var _a;
                (_a = this._logger) === null || _a === void 0 ? void 0 : _a.error(`[IPCBus:Broker] error on close: ${err}`);
            });
            this._server.close();
        }, (reject) => {
            var _a;
            this._server.removeAllListeners();
            const msg = `[IPCBus:Broker] stop, error = timeout (${options.timeoutDelay} ms) on ${JSON.stringify(options)}`;
            (_a = this._logger) === null || _a === void 0 ? void 0 : _a.error(msg);
            reject(msg);
        });
    }
    subscribe(onClose, onError, onConnection) {
        this._onCloseHandler = onClose;
        this._onErrorHandler = onError;
        this._onConnectionHandler = onConnection;
        this._server.on('close', this._onClose);
        this._server.on('error', this._onError);
        this._server.on('connection', this._onConnection);
    }
    unsubscribe() {
        this._onCloseHandler = undefined;
        this._onErrorHandler = undefined;
        this._onConnectionHandler = undefined;
        this._server.off('close', this._onClose);
        this._server.off('error', this._onError);
        this._server.off('connection', this._onConnection);
    }
    _onConnection(socket) {
        const socketWrapper = new NetBrokerClient_1.NetBrokerClient(socket, this._logger);
        this._onConnectionHandler(socketWrapper);
    }
    _onClose() {
        var _a;
        (_a = this._onCloseHandler) === null || _a === void 0 ? void 0 : _a.call(this);
    }
    _onError(error) {
        var _a;
        (_a = this._onErrorHandler) === null || _a === void 0 ? void 0 : _a.call(this, error);
    }
}
exports.NetBrokerServer = NetBrokerServer;
//# sourceMappingURL=NetBrokerServer.js.map