"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NetBrokerServerFactory = void 0;
const universal_1 = require("@electron-common-ipc/universal");
const net_1 = require("net");
const NetBrokerServer_1 = require("./NetBrokerServer");
class NetBrokerServerFactory {
    constructor(_logger) {
        this._logger = _logger;
    }
    create(options) {
        if (options.port === undefined && options.path === undefined) {
            throw new Error('Connection options not provided');
        }
        const server = (0, net_1.createServer)();
        server.unref();
        return (0, universal_1.executeInTimeout)(options.timeoutDelay, (resolve, reject) => {
            server.addListener('listening', () => {
                var _a;
                server.removeAllListeners();
                (_a = this._logger) === null || _a === void 0 ? void 0 : _a.info(`[IPCBus:Broker] Listening for incoming connections on ${JSON.stringify(options)}`);
                resolve(new NetBrokerServer_1.NetBrokerServer(server, this._logger));
            });
            server.addListener('error', (err) => {
                const msg = `[IPCBus:Broker] error = ${err} on ${JSON.stringify(options)}`;
                server.removeAllListeners();
                reject(msg);
            });
            server.addListener('close', () => {
                const msg = `[IPCBus:Broker] close on ${JSON.stringify(options)}`;
                reject(msg);
            });
            if (options.path) {
                server.listen(options.path);
            }
            else if (options.port && options.host) {
                server.listen(options.port, options.host);
            }
            else {
                server.listen(options.port);
            }
        }, (reject) => {
            const msg = `[IPCBus:Broker] error = timeout (${options.timeoutDelay} ms) on ${JSON.stringify(options)}`;
            reject(msg);
        });
    }
}
exports.NetBrokerServerFactory = NetBrokerServerFactory;
//# sourceMappingURL=NetBrokerServerFactory.js.map