"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IpcBusConnectorRenderer = exports.IPCBUS_TRANSPORT_RENDERER_LOGROUNDTRIP = exports.IPCBUS_TRANSPORT_RENDERER_MESSAGE = exports.IPCBUS_TRANSPORT_RENDERER_COMMAND = exports.IPCBUS_TRANSPORT_RENDERER_HANDSHAKE = void 0;
const universal_1 = require("@electron-common-ipc/universal");
const queueMicrotask = require("queue-microtask");
const utils_1 = require("../utils");
const IpcBusCommand_helpers_1 = require("../utils/IpcBusCommand-helpers");
exports.IPCBUS_TRANSPORT_RENDERER_HANDSHAKE = 'ECIPC:IpcBusRenderer:Handshake';
exports.IPCBUS_TRANSPORT_RENDERER_COMMAND = 'ECIPC:IpcBusRenderer:RendererCommand';
exports.IPCBUS_TRANSPORT_RENDERER_MESSAGE = 'ECIPC:IpcBusRenderer:RendererMessage';
exports.IPCBUS_TRANSPORT_RENDERER_LOGROUNDTRIP = 'ECIPC:IpcBusRenderer:RendererLogRoundtrip';
class IpcBusConnectorRenderer extends universal_1.IpcBusConnectorImpl {
    constructor(uuid, contextType, _isMainFrame, ipcWindow) {
        super(uuid, contextType, 'connector-renderer');
        this._isMainFrame = _isMainFrame;
        this._ipcWindow = ipcWindow;
        this._messageBag = new IpcBusCommand_helpers_1.SmartMessageBag();
        this.onPortMessageReceived = this.onPortMessageReceived.bind(this);
        this.onPortCommandReceived = this.onPortCommandReceived.bind(this);
        this.onIPCMessageReceived = this.onIPCMessageReceived.bind(this);
        this.onIPCCommandReceived = this.onIPCCommandReceived.bind(this);
    }
    handshakeInternal(client, peer, options) {
        return this.onIPCHandshake(client, peer, options);
    }
    shutdownInternal() {
        this.removeIpcListeners();
        this.onConnectorShutdown();
        return Promise.resolve();
    }
    postMessage(ipcMessage, args, messagePorts) {
        var _a;
        this._messageBag.set(ipcMessage, args);
        if (!messagePorts) {
            const target = (0, IpcBusCommand_helpers_1.GetTargetRenderer)(ipcMessage, true);
            if (target && ((_a = target.process) === null || _a === void 0 ? void 0 : _a.isMainFrame)) {
                this._messageBag.sendIPCMessageTo(this._ipcWindow, target.process.wcid, exports.IPCBUS_TRANSPORT_RENDERER_MESSAGE);
            }
            else {
                this._messageBag.sendIPCMessage(this._ipcWindow, exports.IPCBUS_TRANSPORT_RENDERER_MESSAGE);
            }
            return;
        }
        this._messageBag.sendPortMessage(this._messageChannel.port1, messagePorts);
    }
    postCommand(ipcCommand) {
        this._ipcWindow.send(exports.IPCBUS_TRANSPORT_RENDERER_COMMAND, ipcCommand);
    }
    postLogRoundtrip(ipcMessage, args) {
        this._messageBag.set(ipcMessage, args);
        this._messageBag.sendIPCMessage(this._ipcWindow, exports.IPCBUS_TRANSPORT_RENDERER_LOGROUNDTRIP);
    }
    removeIpcListeners() {
        this._ipcWindow.removeListener(exports.IPCBUS_TRANSPORT_RENDERER_MESSAGE, this.onIPCMessageReceived);
        this._ipcWindow.removeListener(exports.IPCBUS_TRANSPORT_RENDERER_COMMAND, this.onIPCCommandReceived);
        if (this._messageChannel) {
            this._messageChannel.port1.removeEventListener('message', this.onPortMessageReceived);
            this._messageChannel.port1.close();
            this._messageChannel = undefined;
        }
        if (this._commandChannel) {
            this._commandChannel.port1.removeEventListener('message', this.onPortCommandReceived);
            this._commandChannel.port1.close();
            this._commandChannel = undefined;
        }
    }
    onIPCMessageReceived(event, ipcMessage, data) {
        queueMicrotask(() => {
            if (ipcMessage.isRawData) {
                const ipcPacketBufferCore = (0, utils_1.fixRawData)(data);
                this._client.onConnectorPacketReceived(ipcMessage, ipcPacketBufferCore);
            }
            else {
                this._client.onConnectorArgsReceived(ipcMessage, data);
            }
        });
    }
    onPortMessageReceived(event) {
        queueMicrotask(() => {
            const [ipcMessage, data] = event.data;
            if (ipcMessage.isRawData) {
                const ipcPacketBufferCore = (0, utils_1.fixRawData)(data);
                this._client.onConnectorPacketReceived(ipcMessage, ipcPacketBufferCore, event.ports);
            }
            else {
                this._client.onConnectorArgsReceived(ipcMessage, data, event.ports);
            }
        });
    }
    onIPCCommandReceived(_event, ipcCommand) {
        this._client.onConnectorCommandBase(ipcCommand);
    }
    onPortCommandReceived(event) {
        const ipcCommand = event.data;
        this._client.onConnectorCommandBase(ipcCommand);
    }
    onIPCHandshake(client, peer, _options) {
        return new Promise((resolve) => {
            let timer;
            const onHandshake = (_event, handshake) => {
                clearTimeout(timer);
                this._ipcWindow.addListener(exports.IPCBUS_TRANSPORT_RENDERER_MESSAGE, this.onIPCMessageReceived);
                this._ipcWindow.addListener(exports.IPCBUS_TRANSPORT_RENDERER_COMMAND, this.onIPCCommandReceived);
                this.addClient(client);
                this._messageChannel.port1.addEventListener('message', this.onPortMessageReceived);
                this._messageChannel.port1.start();
                resolve(handshake);
            };
            peer.process = { isMainFrame: this._isMainFrame, pid: -1 };
            this._messageChannel = new MessageChannel();
            this._ipcWindow.once(exports.IPCBUS_TRANSPORT_RENDERER_HANDSHAKE, onHandshake);
            this._ipcWindow.postMessage(exports.IPCBUS_TRANSPORT_RENDERER_HANDSHAKE, { peer }, [this._messageChannel.port2]);
        });
    }
    onPortHandshake(client, peer, _options) {
        return new Promise((resolve) => {
            let timer;
            const onHandshake = (event) => {
                clearTimeout(timer);
                this._ipcWindow.addListener(exports.IPCBUS_TRANSPORT_RENDERER_MESSAGE, this.onIPCMessageReceived);
                this._commandChannel.port1.addEventListener('message', this.onPortCommandReceived);
                this._commandChannel.port1.removeEventListener('message', onHandshake);
                this._messageChannel.port1.addEventListener('message', this.onPortMessageReceived);
                this._messageChannel.port1.start();
                this.addClient(client);
                const handshake = event.data;
                resolve(handshake);
            };
            this._messageChannel = new MessageChannel();
            peer.process = { isMainFrame: this._isMainFrame, pid: -1 };
            this._commandChannel = new MessageChannel();
            this._commandChannel.port1.addEventListener('message', onHandshake);
            this._commandChannel.port1.start();
            this._ipcWindow.postMessage(exports.IPCBUS_TRANSPORT_RENDERER_HANDSHAKE, { peer }, [
                this._messageChannel.port2,
                this._commandChannel.port2,
            ]);
        });
    }
}
exports.IpcBusConnectorRenderer = IpcBusConnectorRenderer;
//# sourceMappingURL=IpcBusConnectorRenderer.js.map