"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.preloadElectronCommonIpc = exports.createIpcBusClient = void 0;
const universal_1 = require("@electron-common-ipc/universal");
const IpcBusClientRenderer_factory_1 = require("./IpcBusClientRenderer-factory");
const IpcBusWindowNamespace_1 = require("./IpcBusWindowNamespace");
const utils_1 = require("../utils");
const trace = false;
function createIpcBusClient(window, ipcWindow) {
    trace && console.log(`${IpcBusWindowNamespace_1.ElectronCommonIpcNamespace}.CreateIpcBusClient`);
    const ipcBusClient = (0, IpcBusClientRenderer_factory_1.newIpcBusClient)(2, window.self === window.top, ipcWindow);
    return ipcBusClient;
}
exports.createIpcBusClient = createIpcBusClient;
function createGlobals(windowLocal, ipcWindow) {
    return {
        CreateIpcBusClient: () => createIpcBusClient(windowLocal, ipcWindow),
    };
}
function exposeProxyClient(window, ipcWindow) {
    const client = createIpcBusClient(window, ipcWindow);
    return {
        CreateIpcBusClient: () => client,
    };
}
const ContextIsolationDefaultValue = false;
const gPreloadDoneSymbolName = '_PreloadElectronCommonIpc';
function _preloadElectronCommonIpc(contextIsolation) {
    if (contextIsolation === undefined) {
        contextIsolation = ContextIsolationDefaultValue;
    }
    const globalContainer = new universal_1.GlobalContainer();
    const isPreloadDone = globalContainer.getSingleton(gPreloadDoneSymbolName);
    if (!isPreloadDone) {
        globalContainer.registerSingleton(gPreloadDoneSymbolName, true);
        const electron = (0, utils_1.requireElectron)();
        const ipcRenderer = electron === null || electron === void 0 ? void 0 : electron.ipcRenderer;
        if (ipcRenderer) {
            const windowLocal = window;
            if (contextIsolation) {
                try {
                    electron.contextBridge.exposeInMainWorld(IpcBusWindowNamespace_1.ElectronCommonIpcNamespace, exposeProxyClient(windowLocal, ipcRenderer));
                }
                catch (error) {
                    console.error(error);
                    contextIsolation = false;
                }
            }
            if (!contextIsolation) {
                windowLocal[IpcBusWindowNamespace_1.ElectronCommonIpcNamespace] = createGlobals(windowLocal, ipcRenderer);
            }
        }
    }
    return (0, IpcBusWindowNamespace_1.isIpcAvailable)();
}
function preloadElectronCommonIpc(contextIsolation) {
    return _preloadElectronCommonIpc(contextIsolation);
}
exports.preloadElectronCommonIpc = preloadElectronCommonIpc;
//# sourceMappingURL=IpcBusRendererPreload.js.map