"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createProcessID = exports.requireElectron = exports.fixRawData = exports.buffersToList = exports.IPC_BUS_TIMEOUT = void 0;
const universal_1 = require("@electron-common-ipc/universal");
const json_helpers_1 = require("json-helpers");
const socket_serializer_1 = require("socket-serializer");
const IpcBusRendererContent_1 = require("../renderer/IpcBusRendererContent");
exports.IPC_BUS_TIMEOUT = 2000;
function buffersToList(buffers) {
    const header = socket_serializer_1.IpcPacketHeader.ReadHeader(new socket_serializer_1.BufferReader(buffers[0]));
    return new socket_serializer_1.IpcPacketBufferList(Object.assign({ buffers }, header));
}
exports.buffersToList = buffersToList;
function fixRawData(realData) {
    (0, IpcBusRendererContent_1.FixRawContent)(realData);
    const ipcPacketBufferCore = realData.buffer ? new socket_serializer_1.IpcPacketBuffer(realData) : new socket_serializer_1.IpcPacketBufferList(realData);
    ipcPacketBufferCore.JSON = json_helpers_1.JSONParserV1;
    return ipcPacketBufferCore;
}
exports.fixRawData = fixRawData;
function requireElectron() {
    try {
        const electron = require('electron');
        return electron;
    }
    catch (err) {
        return undefined;
    }
}
exports.requireElectron = requireElectron;
function createProcessID(peer, ipcProcess) {
    let name = `${(0, universal_1.convertProcessTypeToString)(peer.type)}`;
    if (ipcProcess.wcid) {
        name += `-${ipcProcess.wcid}`;
    }
    if (ipcProcess.rid && ipcProcess.rid !== ipcProcess.wcid) {
        name += `-r${ipcProcess.rid}`;
    }
    if (ipcProcess.frameid) {
        name += `-f${ipcProcess.isMainFrame ? 'm' : 's'}${ipcProcess.frameid}`;
    }
    if (ipcProcess.pid) {
        name += `-p${ipcProcess.pid}`;
    }
    return name;
}
exports.createProcessID = createProcessID;
//# sourceMappingURL=index.js.map